import { shallowMount, createLocalVue } from "@vue/test-utils";
import Vuex from "vuex";
import Select from "../../../src/components/LayoutBuilderSelect.vue";
import state from "../../mocks/state";
import Store from "../../../src/store/index";

const localVue = createLocalVue();
const store = Store(state);

localVue.use(Vuex);

describe("Select.vue", () => {
  const stub = jest.fn();
  Select.methods.changeLayout = stub;

  const wrapper = shallowMount(Select, {
    propsData: {
      indexSection: 1,
      section: {
        layout: "LayoutOneColumn"
      }
    },
    store,
    localVue
  });

  it("uses the keys of Vue.prototype.$layouts for the select", () => {
    expect(wrapper.find("option:nth-child(1)").text()).toBe("- Layout -");
    expect(wrapper.find("option:nth-child(2)").text()).toBe("LayoutOneColumn");
    expect(wrapper.find("option:nth-child(3)").text()).toBe(
      "LayoutThreeColumns"
    );
  });

  it("sets the value of the component to section.layout", () => {
    expect(wrapper.element.value).toBe("LayoutOneColumn");
  });

  it("calls changeLayout() with the correct params when changing the select", () => {
    wrapper.element.value = "LayoutThreeColumns";
    wrapper.trigger("change");
    expect(Select.methods.changeLayout).toHaveBeenCalledWith({
      indexSection: 1,
      selectedLayout: "LayoutThreeColumns"
    });
  });

  describe("layouts()", () => {
    it("returns an array with the keys of Vue.prototype.$layouts", () => {
      expect(wrapper.vm.layouts).toEqual([
        "LayoutOneColumn",
        "LayoutThreeColumns",
        "LayoutTwoColumns"
      ]);
    });
  });
});
